# Copyright 2017 FUJITSU LIMITED
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

"""
Use this file for deploying the API under mod_wsgi.
"""

from paste import deploy

application = None


def main():
    base_dir = '/etc/monasca/'
    conf = '{0}events-api-paste.ini'.format(base_dir)
    app = deploy.loadapp('config:{0}'.format(conf))
    return app

if __name__ == '__main__' or __name__.startswith('_mod_wsgi'):
    application = main()
